# Tanjun

A flexible command framework designed to extend Hikari.

# Installation

You can install Tanjun from PyPI using the following command in any Python 3.9 or above environment.

```
python -m pip install -U hikari-tanjun
```

# Quick Usage

For usage see the [documentation](https://tanjun.cursed.solutions/),
[usage guide](https://tanjun.cursed.solutions/usage/), and
[tutorials and articles](https://patchwork.systems/programming/hikari-discord-bot/index.html).

# Community Resources

* [Tan-chan](https://github.com/FasterSpeeding/Tan-chan) is a general utility library for
  Tanjun. It includes a command annotation parsing extension which parses docstrings to
  get the descriptions of slash commands and their options.
* Redis based implementations of the async cache dependency can be found in
  [hikari-sake](https://github.com/FasterSpeeding/Sake) \>=v1.0.1a1 (exposed by
  [sake.redis.ResourceClient.add_to_tanjun][]).

# Support

[Hikari's support guild](https://discord.gg/hikari) provides for support for Tanjun.

# Contributing

Before contributing you should read through the
[contributing guidelines](https://github.com/FasterSpeeding/Tanjun/blob/master/CONTRIBUTING.md) and
the [code of conduct](https://github.com/FasterSpeeding/Tanjun/blob/master/CODE_OF_CONDUCT.md).
